<h1 align="center">react-native-user-detector-active-inactive</h1>

> React Native component that notifies if the user is active or not (i.e. when the app surface hasn't been touched for more than a certain amount of ms).

As of version 1.1.0, `react-native-user-detector-active-inactive` resets the timer also when the keyboard appears or disappears.
If you want to avoid this behaviour, you can set the `skipKeyboard` property to `true`.

## Install

```sh
npm install react-native-user-detector-active-inactive
```

## 🔑 Key features

## ❔ How to use

This package primarily exposes a single functional component, [UserInactivity](src/index.js).
The signature of the `UserInactivity` React props is the following:

```typescript
interface UserInactivityProps<T = unknown> {
  /**
   * Number of seconds after which the view is considered inactive.
   * If it changed, the timer restarts and the view is considered active until
   * the new timer expires.
   * It defaults to  second when you send a props at timeForInactivity .
   */
  timeForInactivity?: number;
  /**
   * If it's explicitly set to `true` after the component has already been initialized,
   * the timer restarts and the view is considered active until the new timer expires.
   * It defaults to true when set to props .
   */
  isActive?: boolean;
  /**
   * Children components to embed inside UserInactivity's View.
   * If any children component is pressed, `onAction` is called after
   * `timeForInactivity` seconds. not millisecond
   */
  children: React.ReactNode;
  /**
   * If set to true, the timer will be to reset and start again from 0  when the keyboard appears
   * if set to false, the timer will not to be reset
   */
  skipKeyboard?: boolean;
  /**
   * Optional custom style for UserInactivity's View.
   * It defaults to { flex: 1 }.
   */
  style?: StyleProp<ViewStyle>;
}
```

```tsx
import UserInactivity from "react-native-user-detector-active-inactive";
export default () => {
  const [currentRoute, setCurrentRoute] = useState("");
  const onStateChange = (state: any) => {
    setCurrentRoute(state?.routes[state.index]?.name);
  };
  return (
    <Provider store={store}>
      <SafeAreaProvider>
        <UserInactivity
          currentScreen={currentRoute}
          isActive={true}
          skipKeyboard={true}
        >
          <NavigationContainer
            theme={appTheme as any}
            ref={navigationRef}
            onStateChange={onStateChange}
          >
            <Routes />
          </NavigationContainer>
        </UserInactivity>
      </SafeAreaProvider>
    </Provider>
  );
};
```
