import React from "react";
import { StyleProp, ViewStyle } from "react-native";
export interface UserInactivityProps<T = unknown> {
  /**
   * Number of seconds after which the view is considered inactive.
   * If it changed, the timer restarts and the view is considered active until
   * the new timer expires.
   * It defaults to  second when you send a props at timeForInactivity .
   */
  timeForInactivity?: number;
  /**
   * If it's explicitly set to `true` after the component has already been initialized,
   * the timer restarts and the view is considered active until the new timer expires.
   * It defaults to true when set to props .
   */
  isActive?: boolean;
  /**
   * Children components to embed inside UserInactivity's View.
   * If any children component is pressed, `onAction` is called after
   * `timeForInactivity` seconds. not millisecond
   */
  children: React.ReactNode;
  /**
   * If set to true, the timer will be to reset and start again from 0  when the keyboard appears
   * if set to false, the timer will not to be reset
   */
  skipKeyboard?: boolean;
  /**
   * Optional custom style for UserInactivity's View.
   * It defaults to { flex: 1 }.
   */
  style?: StyleProp<ViewStyle>;
  currentScreen?: any;
}
declare const UserInactivity: React.FC<UserInactivityProps>;
export default UserInactivity;
